@@ -3,14 +3,18 @@
 # are not yet marked Fix Released in Launchpad
 
 import getopt
+import importlib.util
 import re
 import sys
 
+if not importlib.util.find_spec("launchpadlib.launchpad"):
+    print("Please install launchpadlib")
+    sys.exit(1)
+
 try:
-    from launchpadlib.launchpad import Launchpad
     from lazr.restfulclient import errors
 except ModuleNotFoundError:
-    print("Please install launchpadlib from lp:launchpadlib")
+    print("Please install lazr.restfulclient")
     sys.exit(1)
 try:
     import hydrazine
@@ -38,12 +42,12 @@ if len(args) == 1:
 def report_notmarked(bug, task, section):
     print()
     print("Bug %d was mentioned in NEWS but is not marked fix released:" % (bug.id,))
-    print("Launchpad title: %s" % bug.title)
+    print("Launchpad title: {}".format(bug.title))
     print("NEWS summary: ")
     print(section)
     if "--launchpad" in options or "-l" in options:
         print("  bug %d" % bug.id)
-        print("  affects %s" % task.bug_target_name)
+        print("  affects {}".format(task.bug_target_name))
         print("  status fixreleased")
     if "--webbrowser" in options or "-w" in options:
         import webbrowser
@@ -52,7 +56,7 @@ def report_notmarked(bug, task, section):
 
 
 def read_news_bugnos(path):
-    """Read the bug numbers closed by a particular NEWS file
+    """Read the bug numbers closed by a particular NEWS file.
 
     Args:
       path: Path to the NEWS file
@@ -114,7 +118,7 @@ for bugno, section in bugnos:
 
     if not found_brz:
         print_bug_url(bugno)
-        print("Bug %d was mentioned in NEWS but is not marked as affecting brz" % bugno)
+        print(f"Bug {bugno} was mentioned in NEWS but is not marked as affecting brz")
     elif not fix_released:
         print_bug_url(bugno)
         report_notmarked(bug, task, section)
